==> kdepim-4.10.5.tar.xz: kdepim-4.10.5/examples/etm_usage/collectionmonitoredwidget.h <==
/*
    Copyright (C) 2010 Klarälvdalens Datakonsult AB,
        a KDAB Group company, info@kdab.net,
        author Stephen Kelly <stephen@kdab.com>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

// READ THE README FILE

#ifndef COLLECTIONMONITOREDWIDGET_H
#define COLLECTIONMONITOREDWIDGET_H

#include <QWidget>

class QItemSelection;

class EntityTreeWidget;

namespace Akonadi
{
class ChangeRecorder;
class EntityTreeView;
}

class CollectionMonitoredWidget : public QWidget
{
  Q_OBJECT
public:
  CollectionMonitoredWidget(QWidget* parent = 0, Qt::WindowFlags f = 0);

private slots:
  void selectionChanged(const QItemSelection &selected,const QItemSelection &deselected);

private:
  EntityTreeWidget *m_etw;
  Akonadi::ChangeRecorder *m_oneCollectionChangeRecorder;
  Akonadi::EntityTreeView *m_oneCollectionView;

};

#endif

==> kdepim-15.08.1.tar.xz: kdepim-15.08.1/examples/etm_usage/collectionmonitoredwidget.h <==
/*
    Copyright (C) 2010 Klarälvdalens Datakonsult AB,
        a KDAB Group company, info@kdab.net,
        author Stephen Kelly <stephen@kdab.com>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

// READ THE README FILE

#ifndef COLLECTIONMONITOREDWIDGET_H
#define COLLECTIONMONITOREDWIDGET_H

#include <QWidget>

class QItemSelection;

class EntityTreeWidget;

namespace Akonadi
{
class ChangeRecorder;
class EntityTreeView;
}

class CollectionMonitoredWidget : public QWidget
{
    Q_OBJECT
public:
    CollectionMonitoredWidget(QWidget *parent = Q_NULLPTR, Qt::WindowFlags f = 0);

private Q_SLOTS:
    void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);

private:
    EntityTreeWidget *m_etw;
    Akonadi::ChangeRecorder *m_oneCollectionChangeRecorder;
    Akonadi::EntityTreeView *m_oneCollectionView;

};

#endif
